Pro xshooter_darkfixer,darklist,combdark,combdarkvar

;+-------------------------------------------------------------------------
;
; XSHOOTER_DARKFIXER     11/2012
;
; Mean combine dark frames.  Rejects bad pixels.
;
; INPUTS
;       darklist    - String, name of single-column ASCII file
;                     containing the FITS filenames of darks to be
;                     combined, OR string array of FITS filenames of
;                     darks to be combined.
;
; OUTPUTS
;       combdark    - Mean-combined dark frame.  May either be a
;                     variable or a fits filename to which array is to
;                     be written.
;       combflatvar - Formal variance in the combined dark.  May
;                     either be a variable or a fits filename to which
;                     array is to be written.
;
; HISTORY
;       Written 11/2/2012 GDB
;--------------------------------------------------------------------------

if (n_params() eq 0) then begin
   print,'CALLING SEQUENCE:  '
   print,' xshooter_darkfixer,darklist,combdark,combdarkvar'
   return
endif

;;; Read in dark filenames
darklist_sz = size(darklist)
if (darklist_sz(0) eq 0) then begin
   ; ASCII file with names of dark fields
   dark_templ = {   $
          version: 1.0, $
          datastart: 0L, $
          delimiter: ' ', $
          missingvalue: -99.0, $
          commentsymbol: '#', $
          fieldcount: 1L, $
          fieldtypes: [7L], $
          fieldnames: ['name'], $
          fieldlocations: [6L], $
          fieldgroups: [0L] $
        }
   list     = read_ascii(darklist,template=dark_templ)
   darkfile = list.name
endif else begin
   ; Array with names of dark fields
   darkfile = darklist
endelse
n_dark = n_elements(darkfile)

;;; Read in dark exposures

; Array size
test = readfits(darkfile(0),dark_hdr)
sz   = size(test)
xsz  = sz(1)
ysz  = sz(2)

; Read in exposures
big_dark = fltarr(xsz,ysz,n_dark)
for i=0,n_dark-1 do $
   big_dark(*,*,i) = readfits(darkfile(i),hdark)

;;; Combine pixel-by-pixel, rejecting cosmic rays

mean_dark = fltarr(xsz,ysz) 
var_dark  = fltarr(xsz,ysz)
nsig = 5.
for i=0,xsz-1 do begin
   for j=0,ysz-1 do begin
      pix = big_dark(i,j,*)
      med = median(pix,/even)
      if (n_dark gt 2) then begin
         if (n_dark ge 4) then sdev = robust_sigma(pix) else $
            sdev = stddev(pix)
	 if (sdev eq 0) then begin
	    keep_ls = lindgen(n_dark)
	    n_keep  = n_dark
	 endif else begin
            keep_ls = where(abs(pix-med) lt nsig*sdev,n_keep)
         endelse
      endif else begin
         keep_ls = lindgen(n_dark)
	 n_keep  = n_dark
      endelse
      mean_dark(i,j) = mean(pix(keep_ls))
      var_dark(i,j)  = variance(pix(keep_ls)) / n_keep
   endfor
endfor

;;; Set output arrays or write fits files

hnormdark = dark_hdr
sxaddhist,'-------------------------------------------------------',hnormdark
sxaddhist,'Darkfield processing done using XSHOOTER_DARKFIXER',hnormdark
sxaddhist,'   Darkfield frames combined:',hnormdark
for i=0,n_dark-1 do $
   sxaddhist,'      '+darkfile(i),hnormdark
sxaddhist,'-------------------------------------------------------',hnormdark

sxaddpar,hnormdark,'BZERO',0.0

if (size(combdark,/tname) eq 'STRING') then begin
   print,'Writing '+combdark
   writefits,combdark,mean_dark,hnormdark
endif else combdark = mean_dark

if (size(combdarkvar,/tname) eq 'STRING') then begin
   print,'Writing '+combdarkvar
   writefits,combdarkvar,var_dark,hnormdark
endif else combdarkvar = var_dark

print,'Done.'

return
end
