Function xshooter_subbias,raw,arm=arm

;+------------------------------------------------------------------------
;
; XSHOOTER_SUBBIAS      4/2010 GDB
;
; Bias-subtract X-Shooter frame.
;
; Does row-by row median subtraction for the UVB and VIS arms.  No
; subtraction is done for the NIR arm.
;
; INPUTS
;          raw     - Raw frame, can be a 2D array or the name of the
;                    FITS file.
;
; KEYWORDS 
;          arm     - String specifying which X-Shooter arm: 'UVB',
;                    'VIS', or 'NIR'.  Must be set.
;
; OUTPUTS
;          <result> - 2D bias-subtracted array
;
; HISTORY
;          Written 4/21/2010 GDB
;-------------------------------------------------------------------------

if (n_params() eq 0) then begin
   print,'CALLING SEQUENCE:  result = xshooter_subbias(raw,arm=arm)'
   return,-1
endif

;;; Which arm?
if not(keyword_set(arm)) then begin
   print,'Must specify which X-Shooter arm'
   return,-1
endif
; Allow upper or lower case
case arm of
   'uvb': arm = 'UVB'
   'UVB': arm = 'UVB'
   'vis': arm = 'VIS'
   'VIS': arm = 'VIS'
   'nir': arm = 'NIR'
   'NIR': arm = 'NIR'
   else : begin
             print,'X-Shooter arm not recognized'
             return,-1
          end
endcase

;;; Read in FITS file, if necessary
if (size(raw,/tname) eq 'STRING') then begin
   checkexists = findfile(raw,count=nfiles)
   if (nfiles eq 0) then begin
      print,'XSHOOTER_SUBBIAS: Raw file not found.'
      return,-1
   endif else begin
       rawframe = readfits(raw,hrawframe)
       fromfitsfile = 1 
   endelse
endif else rawframe = raw

;;; For NIR, return raw frame
if (arm eq 'NIR') then return,rawframe

;;; Pre/overscan regions
if (arm eq 'UVB') then begin
   scan_lo = 0     ; 1x binning in spatial direction
   scan_hi = 45
endif else begin
   scan_lo = 2067
   scan_hi = 2105
endelse
n_scan = float(scan_hi - scan_lo)

;;; Subtract off median from each row
sz       = size(rawframe)
ysz      = sz(2)
subframe = 1.*rawframe
for i=0,ysz-1 do subframe(*,i) = rawframe(*,i) - $
                                    median(rawframe(scan_lo:scan_hi,i))

return,subframe
end
